@@ -2,6 +2,7 @@ import logging
 import sys
 from collections import deque
 from os import chdir, path
+from typing import no_type_check
 
 import click
 import docker
@@ -58,7 +59,8 @@ _logger = logging.getLogger(__name__)
 @click.option(
     "-y", "--yes", "skip_confirm", is_flag=True, help="Skip confirmation prompt"
 )
-def deploy(buildp, mpath, dpath, nomitall, channel, dry_run, skip_confirm):
+@click.option("-nc", "--no-cache", is_flag=True, help="Do not use the docker cache")
+def deploy(buildp, mpath, dpath, nomitall, channel, dry_run, skip_confirm, no_cache):
     "Build engine docker images and optionally run tests."
     if nomitall == "nomitall-prod":
         nomitall_url = "https://user.api.nomnomdata.com/api/1/"
@@ -99,9 +101,7 @@ def deploy(buildp, mpath, dpath, nomitall, channel, dry_run, skip_confirm):
             "There was a problem connecting to the docker agent, ensure it is running and in a good state"
         ) from e
     build_engine(
-        engine_name=engine_name,
-        channel=channel,
-        docker_file=dpath,
+        engine_name=engine_name, channel=channel, docker_file=dpath, no_cache=no_cache
     )
     if not dry_run:
         deploy_engine(engine_name, channel, data)
@@ -122,7 +122,7 @@ def deploy_engine(engine_name, channel, creds):
     _logger.info("----Successfully pushed image----")
 
 
-def build_engine(engine_name, channel, docker_file, buildargs=None):
+def build_engine(engine_name, channel, docker_file, no_cache=False, buildargs=None):
     client = docker.from_env()
 
     _logger.info(f"----Building image {engine_name}:{channel}----")
@@ -133,6 +133,7 @@ def build_engine(engine_name, channel, docker_file, buildargs=None):
         path=".",
         pull=True,
         buildargs=buildargs,
+        nocache=no_cache,
     )
     deque(stream_output(build_logs, sys.stdout), maxlen=0)
     _logger.info("----Finished building image----")
