@@ -1,5 +1,5 @@
 import logging
-from pprint import pformat, pprint
+from pprint import pformat
 
 from cerberus.validator import Validator
 
@@ -8,19 +8,21 @@ from .code_sql_types import code_types, sql_types
 _logger = logging.getLogger(__name__)
 
 parameter_types = [
-    "code",
-    "json",
-    "sql",
-    "metadata_table",
     "boolean",
+    "code",
     "connection",
-    "text",
-    "int",
-    "string",
-    "enum",
-    "enum_list",
     "date",
     "datetime",
+    "enum_list",
+    "enum",
+    "int",
+    "json",
+    "metadata_table",
+    "password",
+    "shared_config",
+    "sql",
+    "string",
+    "text",
     "time",
 ]
 help_schema = {
@@ -40,6 +42,18 @@ parameter_field_schema = {
     "default_choices": {"dependencies": {"type": ["enum_list"]}, "type": "list"},
     "display_type": {"dependencies": {"type": ["enum_list"]}, "type": "string"},
     "connection_type_uuid": {"dependencies": {"type": ["connection"]}, "type": "string"},
+    "shared_config_type_uuid": {
+        "dependencies": {"type": ["shared_config"]},
+        "type": "string",
+    },
+    "categories": {
+        "type": "list",
+        "required": False,
+        "schema": {
+            "type": "dict",
+            "schema": {"name": {"type": "string", "required": True}},
+        },
+    },
     "name": {"type": "string", "required": True},
     "dialect": {
         "type": "string",
@@ -59,13 +73,23 @@ parameter_field_schema = {
             # Bi-lateral dependencies
             # E.G. a field that is a "connection" type must have "connection_type_uuid" as a parameter.
             {"allowed": ["connection"], "dependencies": "connection_type_uuid"},
+            {"allowed": ["shared_config"], "dependencies": "shared_config_type_uuid"},
             {"allowed": ["code", "sql"], "dependencies": "dialect"},
             {"allowed": ["enum", "enum_list"], "dependencies": "choices"},
             # Add above bi-lateral dependencies as "forbidden" so above dependencies are evaluated only once.
-            {"forbidden": ["connection", "code", "sql", "enum", "enum_list", "nested"]},
+            {
+                "forbidden": [
+                    "connection",
+                    "shared_config",
+                    "code",
+                    "sql",
+                    "enum",
+                    "enum_list",
+                    "nested",
+                ]
+            },
         ],
     },
-    "shared_config_type_uuid": {"type": "string", "required": False},
     "shared_field_type_uuid": {"type": "string", "required": False},
     "shared_object_type_uuid": {"type": "string", "required": False},
     "max": {"required": False, "type": "integer"},
@@ -129,6 +153,14 @@ engine_schema = {
             "schema": {"name": {"type": "string", "required": True}},
         },
     },
+    "parameter_categories": {
+        "type": "list",
+        "required": True,
+        "schema": {
+            "type": "dict",
+            "schema": {"name": {"type": "string", "required": True}},
+        },
+    },
     "type": {"allowed": ["engine"], "required": True},
     "actions": {
         "type": "dict",
